MethodChannelSignalrSocket class

An implementation of SignalrSocketPlatform that uses method channels.

Inheritance

Properties

callBack ↔ SignalrSocketCallBack
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect({required String url, required String hubName, required String eventName, required Map<String, String> queryString}) → dynamic
override
disconnect() → dynamic
override
isConnected() → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited